Simd

Struct Simd 

#[repr(simd)]
pub(crate) struct Simd<T: SimdElement, const N: usize>([T; N]);

Tuple Fields

0: [T; N]

Implementations

Source

impl<T: SimdElement, const N: usize> Simd<T, N>

pub(crate) const ZERO: Self

A value of this type where all elements are zeroed out.

pub(crate) const fn from_array(elements: [T; N]) -> Self

pub(crate) const fn splat(value: T) -> Self

pub(crate) const fn extract_dyn(&self, index: usize) -> T

Extract the element at position index. Note that index is not a constant so this operation is not efficient on most platforms. Use for testing only.

pub(crate) const fn as_array(&self) -> &[T; N]

Source

impl<T: SimdElement> Simd<T, 1>

pub(crate) const fn new(x0: T) -> Self

Source

impl<T: SimdElement> Simd<T, 2>

pub(crate) const fn new(x0: T, x1: T) -> Self

Source

impl<T: SimdElement> Simd<T, 4>

pub(crate) const fn new(x0: T, x1: T, x2: T, x3: T) -> Self

Source

impl<T: SimdElement> Simd<T, 8>

pub(crate) const fn new( x0: T, x1: T, x2: T, x3: T, x4: T, x5: T, x6: T, x7: T, ) -> Self

Source

impl<T: SimdElement> Simd<T, 16>

pub(crate) const fn new( x0: T, x1: T, x2: T, x3: T, x4: T, x5: T, x6: T, x7: T, x8: T, x9: T, x10: T, x11: T, x12: T, x13: T, x14: T, x15: T, ) -> Self

Source

impl<T: SimdElement> Simd<T, 32>

pub(crate) const fn new( x0: T, x1: T, x2: T, x3: T, x4: T, x5: T, x6: T, x7: T, x8: T, x9: T, x10: T, x11: T, x12: T, x13: T, x14: T, x15: T, x16: T, x17: T, x18: T, x19: T, x20: T, x21: T, x22: T, x23: T, x24: T, x25: T, x26: T, x27: T, x28: T, x29: T, x30: T, x31: T, ) -> Self

Source

impl<const N: usize> Simd<f16, N>

pub(crate) const fn to_bits(self) -> Simd<u16, N>

pub(crate) const fn from_bits(bits: Simd<u16, N>) -> Self

Source

impl<const N: usize> Simd<f32, N>

pub(crate) const fn to_bits(self) -> Simd<u32, N>

pub(crate) const fn from_bits(bits: Simd<u32, N>) -> Self

Source

impl<const N: usize> Simd<f64, N>

pub(crate) const fn to_bits(self) -> Simd<u64, N>

pub(crate) const fn from_bits(bits: Simd<u64, N>) -> Self

Source

impl Simd<u8, 16>

pub(crate) const fn as_m128i(self) -> __m128i

Available on x86 or x86-64 only.
Source

impl Simd<u16, 8>

pub(crate) const fn as_m128i(self) -> __m128i

Available on x86 or x86-64 only.
Source

impl Simd<u32, 4>

pub(crate) const fn as_m128i(self) -> __m128i

Available on x86 or x86-64 only.
Source

impl Simd<u64, 2>

pub(crate) const fn as_m128i(self) -> __m128i

Available on x86 or x86-64 only.
Source

impl Simd<i8, 16>

pub(crate) const fn as_m128i(self) -> __m128i

Available on x86 or x86-64 only.
Source

impl Simd<i16, 8>

pub(crate) const fn as_m128i(self) -> __m128i

Available on x86 or x86-64 only.
Source

impl Simd<i32, 4>

pub(crate) const fn as_m128i(self) -> __m128i

Available on x86 or x86-64 only.
Source

impl Simd<i64, 2>

pub(crate) const fn as_m128i(self) -> __m128i

Available on x86 or x86-64 only.
Source

impl Simd<u8, 32>

pub(crate) const fn as_m256i(self) -> __m256i

Available on x86 or x86-64 only.
Source

impl Simd<u16, 16>

pub(crate) const fn as_m256i(self) -> __m256i

Available on x86 or x86-64 only.
Source

impl Simd<u32, 8>

pub(crate) const fn as_m256i(self) -> __m256i

Available on x86 or x86-64 only.
Source

impl Simd<u64, 4>

pub(crate) const fn as_m256i(self) -> __m256i

Available on x86 or x86-64 only.
Source

impl Simd<i8, 32>

pub(crate) const fn as_m256i(self) -> __m256i

Available on x86 or x86-64 only.
Source

impl Simd<i16, 16>

pub(crate) const fn as_m256i(self) -> __m256i

Available on x86 or x86-64 only.
Source

impl Simd<i32, 8>

pub(crate) const fn as_m256i(self) -> __m256i

Available on x86 or x86-64 only.
Source

impl Simd<i64, 4>

pub(crate) const fn as_m256i(self) -> __m256i

Available on x86 or x86-64 only.
Source

impl Simd<u8, 64>

pub(crate) const fn as_m512i(self) -> __m512i

Available on x86 or x86-64 only.
Source

impl Simd<u16, 32>

pub(crate) const fn as_m512i(self) -> __m512i

Available on x86 or x86-64 only.
Source

impl Simd<u32, 16>

pub(crate) const fn as_m512i(self) -> __m512i

Available on x86 or x86-64 only.
Source

impl Simd<u64, 8>

pub(crate) const fn as_m512i(self) -> __m512i

Available on x86 or x86-64 only.
Source

impl Simd<i8, 64>

pub(crate) const fn as_m512i(self) -> __m512i

Available on x86 or x86-64 only.
Source

impl Simd<i16, 32>

pub(crate) const fn as_m512i(self) -> __m512i

Available on x86 or x86-64 only.
Source

impl Simd<i32, 16>

pub(crate) const fn as_m512i(self) -> __m512i

Available on x86 or x86-64 only.
Source

impl Simd<i64, 8>

pub(crate) const fn as_m512i(self) -> __m512i

Available on x86 or x86-64 only.
Source

impl Simd<f32, 4>

pub(crate) const fn as_m128(self) -> __m128

Available on x86 or x86-64 only.
Source

impl Simd<f64, 2>

pub(crate) const fn as_m128d(self) -> __m128d

Available on x86 or x86-64 only.
Source

impl Simd<f32, 8>

pub(crate) const fn as_m256(self) -> __m256

Available on x86 or x86-64 only.
Source

impl Simd<f64, 4>

pub(crate) const fn as_m256d(self) -> __m256d

Available on x86 or x86-64 only.
Source

impl Simd<f32, 16>

pub(crate) const fn as_m512(self) -> __m512

Available on x86 or x86-64 only.
Source

impl Simd<f64, 8>

pub(crate) const fn as_m512d(self) -> __m512d

Available on x86 or x86-64 only.
Source

impl Simd<u16, 8>

pub(crate) const fn as_m128bh(self) -> __m128bh

Available on x86 or x86-64 only.
Source

impl Simd<u32, 4>

pub(crate) const fn as_m128bh(self) -> __m128bh

Available on x86 or x86-64 only.
Source

impl Simd<i16, 8>

pub(crate) const fn as_m128bh(self) -> __m128bh

Available on x86 or x86-64 only.
Source

impl Simd<i32, 4>

pub(crate) const fn as_m128bh(self) -> __m128bh

Available on x86 or x86-64 only.
Source

impl Simd<u16, 16>

pub(crate) const fn as_m256bh(self) -> __m256bh

Available on x86 or x86-64 only.
Source

impl Simd<u32, 8>

pub(crate) const fn as_m256bh(self) -> __m256bh

Available on x86 or x86-64 only.
Source

impl Simd<i16, 16>

pub(crate) const fn as_m256bh(self) -> __m256bh

Available on x86 or x86-64 only.
Source

impl Simd<i32, 8>

pub(crate) const fn as_m256bh(self) -> __m256bh

Available on x86 or x86-64 only.
Source

impl Simd<u16, 32>

pub(crate) const fn as_m512bh(self) -> __m512bh

Available on x86 or x86-64 only.
Source

impl Simd<u32, 16>

pub(crate) const fn as_m512bh(self) -> __m512bh

Available on x86 or x86-64 only.
Source

impl Simd<i16, 32>

pub(crate) const fn as_m512bh(self) -> __m512bh

Available on x86 or x86-64 only.
Source

impl Simd<i32, 16>

pub(crate) const fn as_m512bh(self) -> __m512bh

Available on x86 or x86-64 only.
Source

impl Simd<f16, 8>

pub(crate) const fn as_m128h(self) -> __m128h

Available on x86 or x86-64 only.
Source

impl Simd<f16, 16>

pub(crate) const fn as_m256h(self) -> __m256h

Available on x86 or x86-64 only.
Source

impl Simd<f16, 32>

pub(crate) const fn as_m512h(self) -> __m512h

Available on x86 or x86-64 only.